@@ -2,14 +2,14 @@ package Web::Request::Role::JSON;
 
 # ABSTRACT: Make handling JSON easier in Web::Request
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 use 5.010;
 use Moose::Role;
 use JSON::MaybeXS;
 use Encode;
 
-sub decoded_json_content {
+sub json_payload {
     my $self = shift;
 
     # Web::Request->content will decode content based on
@@ -80,7 +80,7 @@ Web::Request::Role::JSON - Make handling JSON easier in Web::Request
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ version 1.001
   sub create_POST {
       my ($self, $req) = @_;
 
-      my $data    = $req->decoded_json_content;
+      my $data    = $req->json_payload;
       my $created = $self->model->create($data);
       return $self->json_response($created, undef, 201);
   }
@@ -115,9 +115,9 @@ PSGI response.
 
 =head2 METHODS
 
-=head3 decoded_json_content
+=head3 json_payload
 
-  my $perl_hash = $req->decoded_json_content;
+  my $perl_hash = $req->json_payload;
 
 Extracts and decodes a JSON payload from the request.
 
